@@ -24,6 +24,7 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
+#include <locale.h>
 
 #include "application.h"
 #include "event-manager.h"
@@ -128,12 +129,14 @@ constructed (GObject *object)
 	g_application_set_flags (G_APPLICATION (object), G_APPLICATION_HANDLES_COMMAND_LINE);
 
 	/* Localisation */
+	setlocale (LC_ALL, "");
 	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
 	g_set_application_name (_("Almanah Diary"));
-	gtk_window_set_default_icon_name ("almanah");
+	g_set_prgname ("org.gnome.Almanah");
+	gtk_window_set_default_icon_name ("org.gnome.Almanah");
 
 	/* Chain up to the parent class */
 	G_OBJECT_CLASS (almanah_application_parent_class)->constructed (object);
@@ -287,6 +290,8 @@ startup (GApplication *application)
 	g_object_unref (style_provider);
 
 	/* Shortcuts */
+	add_accelerator(GTK_APPLICATION (application), "app.quit", "<Primary>Q");
+	add_accelerator(GTK_APPLICATION (application), "app.search", "<Primary>F");
 	add_accelerator(GTK_APPLICATION (application), "win.select-date", "<Primary>D");
 	add_accelerator(GTK_APPLICATION (application), "win.bold", "<Primary>B");
 	add_accelerator(GTK_APPLICATION (application), "win.italic", "<Primary>I");
@@ -559,7 +564,7 @@ action_about_cb (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 				 * "Translator name 2 <translator2@email.address>"
 				 */
 				"translator-credits", _("translator-credits"),
-				"logo-icon-name", "almanah",
+				"logo-icon-name", "org.gnome.Almanah",
 				"license", license,
 				"wrap-license", TRUE,
 				"website-label", _("Almanah Website"),
