@@ -351,7 +351,7 @@ import_text_files (AlmanahImportOperation *self, GFile *source, AlmanahImportPro
 	while ((file_info = g_file_enumerator_next_file (enumerator, NULL, &child_error)) != NULL) {
 		AlmanahEntry *entry;
 		GDate parsed_date, last_edited;
-		GTimeVal modification_time;
+		g_autoptr(GDateTime) modification_date_time = NULL;
 		GFile *file;
 		gchar *contents, *message = NULL;
 		gsize length;
@@ -393,9 +393,13 @@ import_text_files (AlmanahImportOperation *self, GFile *source, AlmanahImportPro
 		g_free (contents);
 
 		/* Set the entry's last-edited date */
-		g_file_info_get_modification_time (file_info, &modification_time);
-		g_date_set_time_val (&last_edited, &modification_time);
-		almanah_entry_set_last_edited (entry, &last_edited);
+		modification_date_time = g_file_info_get_modification_date_time (file_info);
+		if (modification_date_time != NULL) {
+			g_date_set_time_t (&last_edited, g_date_time_to_unix (modification_date_time));
+			almanah_entry_set_last_edited (entry, &last_edited);
+		} else {
+			almanah_entry_set_last_edited (entry, &parsed_date);
+		}
 
 		/* Store the entry */
 		status = set_entry (self, entry, display_name, &message);
